@@ -27,10 +27,10 @@ class Schema(collections.Mapping):
 
     KEYS = (
         TYPE, REQUIRED, DESCRIPTION,
-        DEFAULT, CONSTRAINTS, ENTRYSCHEMA
+        DEFAULT, CONSTRAINTS, ENTRYSCHEMA, STATUS
     ) = (
         'type', 'required', 'description',
-        'default', 'constraints', 'entry_schema'
+        'default', 'constraints', 'entry_schema', 'status'
     )
 
     PROPERTY_TYPES = (
@@ -85,6 +85,10 @@ class Schema(collections.Mapping):
     def default(self):
         return self.schema.get(self.DEFAULT)
 
+    @property
+    def status(self):
+        return self.schema.get(self.STATUS, '')
+
     @property
     def constraints(self):
         if not self.constraints_list:
